#!/bin/bash

if test -e include/config/auto.conf; then
        . include/config/auto.conf
else
        echo "Error: auto.conf not generated - run 'make prepare' to create it" >&2
	exit 1
fi

VERSION="${CONFIG_DEEPIN_VERSION}"
PATCHLEVEL="${CONFIG_DEEPIN_PATCHLEVEL}"
AUXRELEASE="${CONFIG_DEEPIN_AUXRELEASE}"

if [ -z "$VERSION" -o -z "$PATCHLEVEL" -o -z "$AUXRELEASE" ]; then
	# This would be a bug in the Kconfig
	cat <<- END >&2
	ERROR: Missing VERSION, PATCHLEVEL, or AUXRELEASE."
	Please check init/Kconfig.suse for correctness.
	END
	exit 1
fi

if [ "$VERSION" = 255 -o "$PATCHLEVEL" = 255 ]; then
	cat <<- END >&2

	ERROR: This release needs to be properly configured.
	Please add real values for DEEPIN_VERSION and DEEPIN_PATCHLEVEL.

	END
	exit 1
fi


case "$CONFIG_DEEPIN_PRODUCT_CODE" in
	0)
		if [ "${PATCHLEVEL}" = "0" ]; then
			SP=""
		else
			SP="${PATCHLEVEL}"
		fi
		DEEPIN_PRODUCT_NAME="DEEPIN SERVER ${VERSION}.${SP}"
		DEEPIN_PRODUCT_SHORTNAME="DEEPIN ${VERSION}.${SP}"
		DEEPIN_PRODUCT_FAMILY="DEEPIN"
		;;
	1)
		DEEPIN_PRODUCT_NAME="DEEPIN Leap ${VERSION}.${PATCHLEVEL}"
		DEEPIN_PRODUCT_SHORTNAME="$DEEPIN_PRODUCT_NAME"
		DEEPIN_PRODUCT_FAMILY="Leap"
		;;
	2)
		DEEPIN_PRODUCT_NAME="DEEPIN Tumbleweed"
		DEEPIN_PRODUCT_SHORTNAME="$DEEPIN_PRODUCT_NAME"
		DEEPIN_PRODUCT_FAMILY="Tumbleweed"
		;;
	*)
		echo "Unknown DEEPIN_PRODUCT_CODE=${CONFIG_DEEPIN_PRODUCT_CODE}" >&2
		exit 1
		;;
esac

DEEPIN_PRODUCT_CODE=$(((${VERSION} << 16) + (${PATCHLEVEL} << 8) + ${AUXRELEASE} ))

cat <<END
#ifndef _DEEPIN_VERSION_H
#define _DEEPIN_VERSION_H

#define DEEPIN_PRODUCT_FAMILY     "${DEEPIN_PRODUCT_FAMILY}"
#define DEEPIN_PRODUCT_NAME       "${DEEPIN_PRODUCT_NAME}"
#define DEEPIN_PRODUCT_SHORTNAME  "${DEEPIN_PRODUCT_SHORTNAME}"
#define DEEPIN_VERSION            ${VERSION}
#define DEEPIN_PATCHLEVEL         ${PATCHLEVEL}
#define DEEPIN_AUXRELEASE		${AUXRELEASE}
#define DEEPIN_PRODUCT_CODE       ${DEEPIN_PRODUCT_CODE}
#define DEEPIN_PRODUCT(version, patchlevel, auxrelease)		\\
	(((version) << 16) +			\\
	 ((patchlevel) << 8) + (auxrelease))

#endif /* _DEEPIN_VERSION_H */
END
